@@ -3,6 +3,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "account/account.h"
 #include "defines/version.h"
 #include "http_errorHandler.h"
 #include "utils/agentLogger.h"
@@ -52,7 +53,7 @@ oidc_error_t curlMemInit() {
  * @return a CURL pointer
  */
 CURL* init() {
-  if (curlMemInit()!=OIDC_SUCCESS) {
+  if (curlMemInit() != OIDC_SUCCESS) {
     return NULL;
   }
 
@@ -70,6 +71,8 @@ CURL* init() {
   return curl;
 }
 
+char* _tmp_cert_path = NULL;
+
 /** @fn void setSSLOpts(CURL* curl)
  * @brief sets SSL options
  * @param curl the curl instance
@@ -79,6 +82,11 @@ void setSSLOpts(CURL* curl, const char* cert_file) {
   curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 1L);
   if (cert_file) {
     curl_easy_setopt(curl, CURLOPT_CAINFO, cert_file);
+  } else {
+    // use default cert path
+    secFree(_tmp_cert_path);
+    _tmp_cert_path = getDefaultCertPath();
+    curl_easy_setopt(curl, CURLOPT_CAINFO, _tmp_cert_path);
   }
 }
 
@@ -147,7 +155,7 @@ void setBasicAuth(CURL* curl, const char* username, const char* password) {
  * @return 0 on success, for error values see \f CURLErrorHandling
  */
 oidc_error_t perform(CURL* curl) {
-  // curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
+  curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
   // curl_easy_setopt(curl, CURLOPT_POSTREDIR, CURL_REDIR_POST_ALL);
   CURLcode     res;
   unsigned int tries   = 0;
