@@ -20,11 +20,13 @@ struct arguments {
   unsigned char json;
   unsigned char quiet;
   unsigned char no_autoreauthenticate;
+  unsigned char restart_on_update;
 
   time_t lifetime;
 
   const char* group;
   const char* socket_path;
+  const char* pid_file;
 
   const char*  command;
   list_t*      args_list;
