@@ -10,9 +10,7 @@ const char* argp_program_version = AGENT_VERSION;
 
 const char* argp_program_bug_address = BUG_ADDRESS;
 
-void           handleOidcdComm(struct ipcPipe pipes, int sock, const char* msg,
-                               const struct arguments* argument);
-_Noreturn void handleClientComm(struct ipcPipe          pipes,
-                                const struct arguments* arguments);
+void handleOidcdComm(struct ipcPipe pipes, int sock, const char* msg,
+                     const struct arguments* argument);
 
 #endif  // OIDC_PROXY_DAEMON_H
